==> haskell-generic-trie-0.3.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 generic-trie
version:              0.3.2
visibility:           public
id:                   generic-trie-0.3.2-5mthPe0bB1fDoqZcFa9FsX
key:                  generic-trie-0.3.2-5mthPe0bB1fDoqZcFa9FsX
license:              BSD-3-Clause
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             http://github.com/glguy/tries
synopsis:             A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.

category:             Data
abi:                  493564e73c3144d6d33f27f5f197875e
exposed:              True
exposed-modules:      Data.GenericTrie Data.GenericTrie.Internal
hidden-modules:       Prelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/generic-trie-0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/generic-trie-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-trie
hs-libraries:         HSgeneric-trie-0.3.2-5mthPe0bB1fDoqZcFa9FsX
depends:              base-4.16.4.0 containers-0.6.5.1 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock

haddock-html:         /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-generic-trie-0.3.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-generic-trie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 generic-trie
version:              0.3.2
visibility:           public
id:                   generic-trie-0.3.2-D0twXH9T6ccF9T3xde8oZF
key:                  generic-trie-0.3.2-D0twXH9T6ccF9T3xde8oZF
license:              BSD-3-Clause
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             http://github.com/glguy/tries
synopsis:             A map, where the keys may be complex structured data.
description:
    This type implements maps where the keys are themselves
    complex structured data.  For example, the keys may be
    the abstract syntax trees for a programming language.
    The map is implemented as a trie, so common parts of the
    keys will be shared in the representation.  The library
    provides a generic implementation of the data structure,
    so values of types that have support for '\''Generic'\'' may
    be automatically used as keys in the map.

category:             Data
abi:                  de93ef2331322154546086adb22c7da6
exposed:              True
exposed-modules:      Data.GenericTrie Data.GenericTrie.Internal
hidden-modules:       Prelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/generic-trie-0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/generic-trie-0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/generic-trie-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-generic-trie
hs-libraries:         HSgeneric-trie-0.3.2-D0twXH9T6ccF9T3xde8oZF
depends:              base-4.17.2.1 containers-0.6.7 transformers-0.5.6.2
haddock-interfaces:
    /usr/share/doc/haskell-generic-trie/html/generic-trie.haddock

haddock-html:         /usr/share/doc/haskell-generic-trie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
